module ActiveFixture
  module Loader
    extend ActiveSupport::Concern


    included do
      class_attribute :fixtures
      self.fixtures = []
    end

    module ClassMethods

      def inherited(base)
        self.load_fixtures(base)
      end

      def load_fixtures(clazz)
        if has_fixture?(clazz)
          source = YAML.load_file(fixture_path(clazz)).with_indifferent_access
          clazz.fixtures = source[clazz.name.underscore.pluralize]
        end
      end

      def has_fixture?(clazz)
        File.exist? fixture_path(clazz)
      end

      def fixture_path(clazz)
        "#{Rails.root}/config/fixtures/#{clazz.name.underscore.pluralize}.yml"
      end

    end


    module InstanceMethods
      def fixtures
        self.class.fixtures
      end
    end
  end
end